==> django-site-warnings-0.2.1.tar.gz: django-site-warnings-0.2.1/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-site-warnings",
    version="0.2.1",
    description="Django application allow to create site warnings, make subscription, and receive notifies.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django extentions", "django manage site"],
    install_requires=requires,
    packages=find_packages("."),
    py_modules=["manage_django_site_warnings_server"],
    zip_safe=False,
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "manage-django-site-warnings-server = manage_django_site_warnings_server:main",
        ]
    },
)

==> django-site-warnings-0.2.2.tar.gz: django-site-warnings-0.2.2/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-site-warnings",
    version="0.2.2",
    description="Django application allow to create site warnings, make subscription, and receive notifies.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhang YiLei",
    author_email="zhangyilei@zencore.cn",
    maintainer="Zhang YiLei",
    maintainer_email="zhangyilei@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django extentions", "django manage site"],
    install_requires=requires,
    packages=find_packages("."),
    py_modules=["manage_django_site_warnings_server"],
    zip_safe=False,
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "manage-django-site-warnings-server = manage_django_site_warnings_server:main",
        ]
    },
)
